@@ -24,7 +24,7 @@ from lightning_utilities.core.apply_func import apply_to_collection
 from lightning_utilities.core.rank_zero import rank_zero_warn
 from torch import Tensor
 from torch.optim import Optimizer
-from torch.utils.data import BatchSampler, DataLoader, DistributedSampler
+from torch.utils.data import BatchSampler, DataLoader, DistributedSampler, RandomSampler
 
 from lightning_lite.plugins import Precision  # avoid circular imports: # isort: split
 from lightning_lite.accelerators.accelerator import Accelerator
@@ -123,7 +123,7 @@ class LightningLite(ABC):
 
     @property
     def is_global_zero(self) -> bool:
-        """Wether this rank is rank zero."""
+        """Whether this rank is rank zero."""
         return self._strategy.is_global_zero
 
     @abstractmethod
@@ -478,6 +478,7 @@ class LightningLite(ABC):
 
     @staticmethod
     def _get_distributed_sampler(dataloader: DataLoader, **kwargs: Any) -> DistributedSampler:
+        kwargs.setdefault("shuffle", isinstance(dataloader.sampler, RandomSampler))
         kwargs.setdefault("seed", int(os.getenv("PL_GLOBAL_SEED", 0)))
         return DistributedSamplerWrapper(dataloader.sampler, **kwargs)
 
